==> static-compat-passwordfile-5.0.12-1-x86_64.pkg.tar.zst: usr/static-compat/share/passwordfile/cmake/passwordfileConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# provide meta-data
set(passwordfile_varname "PASSWORD_FILE")
set(passwordfile_varname "PASSWORD_FILE")
set(PASSWORD_FILE_DISPLAY_NAME "Passwordfile library")
set(PASSWORD_FILE_AUTHOR "Martchus")
set(PASSWORD_FILE_VERSION "5.0.12")
set(PASSWORD_FILE_VERSION_MAJOR "5")
set(PASSWORD_FILE_VERSION_MINOR "0")
set(PASSWORD_FILE_VERSION_PATCH "12")
set(PASSWORD_FILE_GIT_REV_COUNT "")
set(PASSWORD_FILE_GIT_LAST_COMMIT_ID "")
set(PASSWORD_FILE_URL "https://github.com/Martchus/passwordfile")
set(PASSWORD_FILE_DESCRIPTION "C++ library to read/write passwords from/to encrypted files")
set(PASSWORD_FILE_LICENSE "GPL-2.0+")

# define general config
set(PASSWORD_FILE_IS_HEADER_ONLY NO)
set(PASSWORD_FILE_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include")
set(PASSWORD_FILE_BIN_DIR "${PACKAGE_PREFIX_DIR}/bin")
set(PASSWORD_FILE_LIB_DIR "${PACKAGE_PREFIX_DIR}/lib")
set(PASSWORD_FILE_DATA_DIRS "${PACKAGE_PREFIX_DIR}/share/passwordfile")
set(PASSWORD_FILE_MODULE_DIRS "${PACKAGE_PREFIX_DIR}/share/passwordfile/cmake/modules")
set(PASSWORD_FILE_CONFIG_DIRS "${PACKAGE_PREFIX_DIR}/share/passwordfile/cmake")
set(PASSWORD_FILE_PRIVATE_QT_MODULES "")
set(PASSWORD_FILE_PRIVATE_KF_MODULES "")
set(PASSWORD_FILE_PUBLIC_QT_MODULES "")
set(PASSWORD_FILE_PUBLIC_KF_MODULES "")
set(PASSWORD_FILE_REQUIRED_PACKAGES "c++utilities;ZLIB;OpenSSL")
set(PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULES "")
set(PASSWORD_FILE_HAS_QT_TRANSLATION_FILES )
set(PASSWORD_FILE_QT_RESOURCES )

# define mapping from CMake targets to pkg-config module names
set(PKG_CONFIG_passwordfile "passwordfile")

# define additional find_package arguments for required CMake-packages

# define library config, add imported target
set(PASSWORD_FILE_PACKAGE "passwordfile")
set(PASSWORD_FILE_LIB "passwordfile")
set(PASSWORD_FILE_LIB_IS_SHARED "OFF")
set(PASSWORD_FILE_STATIC_LINKAGE "OFF")
if(NOT TARGET "${PASSWORD_FILE_LIB}")
    # make dependencies of the library available
    # caveat: This currently does *not* cover Qt and KF modules which are so far only handled
    #         separately when using the function use_PASSWORD_FILE.

    # prefer static libraries if passwordfile was configured this way during its build
    if (PASSWORD_FILE_STATIC_LINKAGE)
        set(PASSWORD_FILE_DEFAULT_CMAKE_FIND_LIBRARY_SUFFIXES ${CMAKE_FIND_LIBRARY_SUFFIXES})
        if (WIN32)
            set(CMAKE_FIND_LIBRARY_SUFFIXES .a .lib)
        else ()
            set(CMAKE_FIND_LIBRARY_SUFFIXES .a)
        endif ()
        set(PASSWORD_FILE_DEFAULT_PKG_CONFIG_USE_STATIC_LIBS ${PKG_CONFIG_USE_STATIC_LIBS})
        set(PKG_CONFIG_USE_STATIC_LIBS ON)
    endif ()

    # find all required packages
    foreach (_REQUIRED_PACKAGE ${PASSWORD_FILE_REQUIRED_PACKAGES})
        string(REGEX MATCH _REQUIRED_PACKAGE_MATCH "(.*)-([^-]*)" "${_REQUIRED_PACKAGE}")
        if (_REQUIRED_PACKAGE_MATCH)
            set(_REQUIRED_PACKAGE "${CMAKE_MATCH_1}")
            set(_REQUIRED_VERSION "${CMAKE_MATCH_2}")
        else ()
            unset(_REQUIRED_VERSION)
        endif ()
        string(REPLACE "::" "_" _REQUIRED_PACKAGE_VARNAME "${_REQUIRED_PACKAGE}")
        if (PASSWORD_FILE_FIND_PACKAGE_ARGS_${_REQUIRED_PACKAGE_VARNAME})
            set(_FIND_PACKAGE_ARGS ${PASSWORD_FILE_FIND_PACKAGE_ARGS_${_REQUIRED_PACKAGE_VARNAME}})
        else ()
            set(_FIND_PACKAGE_ARGS REQUIRED)
        endif ()
        if (_REQUIRED_VERSION)
            find_package("${_REQUIRED_PACKAGE}" "${_REQUIRED_VERSION}" ${_FIND_PACKAGE_ARGS})
        else ()
            find_package("${_REQUIRED_PACKAGE}" ${_FIND_PACKAGE_ARGS})
        endif()
    endforeach()

    # find all required pkg-config modules
    if (PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULES)
        include(3rdParty)
        foreach (PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULE ${PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULES})
            string(REPLACE "::" "_" PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULE_VARNAME "${PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULE}")
            use_pkg_config_module(
                TARGET_NAME "${PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULE}"
                PKG_CONFIG_MODULES "${PKG_CONFIG_${PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULE_VARNAME}}"
                LIBRARIES_VARIABLE DEV_NULL
                PKG_CONFIG_MODULES_VARIABLE DEV_NULL
            )
        endforeach ()
    endif ()

    # restore preference of static libraries
    if (PASSWORD_FILE_STATIC_LINKAGE)
        set(CMAKE_FIND_LIBRARY_SUFFIXES ${PASSWORD_FILE_DEFAULT_CMAKE_FIND_LIBRARY_SUFFIXES})
        unset(PASSWORD_FILE_DEFAULT_CMAKE_FIND_LIBRARY_SUFFIXES)
        set(PKG_CONFIG_USE_STATIC_LIBS ${PASSWORD_FILE_DEFAULT_PKG_CONFIG_USE_STATIC_LIBS})
        unset(PASSWORD_FILE_DEFAULT_PKG_CONFIG_USE_STATIC_LIBS)
    endif ()

    # add target for the library itself
    include("${CMAKE_CURRENT_LIST_DIR}/passwordfileTargets.cmake")
endif()

# define function to ease use of library in projects following conventions of c++utilities' build script
function(use_PASSWORD_FILE)
    # make CMake modules of the project available
    list(APPEND CMAKE_MODULE_PATH "${PASSWORD_FILE_MODULE_DIRS}")
    set(CMAKE_MODULE_PATH "${CMAKE_MODULE_PATH}" PARENT_SCOPE)

    # parse arguments
    include(3rdParty)
    parse_arguments_for_use_functions(${ARGN})

    # link against library (also "link" against header-only libs to get compile defs and interface link libs)
    link_directories(${PASSWORD_FILE_LIB_DIR})
    if (ARGS_ONLY_HEADERS)
        set(TARGET_NAME "${PASSWORD_FILE_LIB}-headers")
    else ()
        set(TARGET_NAME "${PASSWORD_FILE_LIB}")
    endif ()
    set("${ARGS_LIBRARIES_VARIABLE}" "${${ARGS_LIBRARIES_VARIABLE}};${TARGET_NAME}" PARENT_SCOPE)
    set("${ARGS_PACKAGES_VARIABLE}" "${${ARGS_PACKAGES_VARIABLE}};${PASSWORD_FILE_PACKAGE}" PARENT_SCOPE)

    if (ARGS_ONLY_HEADERS)
        return ()
    endif ()

    # add required Qt and KF modules
    set(IMPORTED_QT_MODULES
        ${IMPORTED_QT_MODULES}
        ${PASSWORD_FILE_PUBLIC_QT_MODULES}
        ${PASSWORD_FILE_PRIVATE_QT_MODULES}
        PARENT_SCOPE
    )
    set(IMPORTED_KF_MODULES
        ${IMPORTED_KF_MODULES}
        ${PASSWORD_FILE_PUBLIC_KF_MODULES}
        ${PASSWORD_FILE_PRIVATE_KF_MODULES}
        PARENT_SCOPE
    )

    # add required translations to APP_SPECIFIC_QT_TRANSLATION_FILES_ARRAY
    if(PASSWORD_FILE_HAS_QT_TRANSLATION_FILES)
        set(APP_SPECIFIC_QT_TRANSLATION_FILES "${APP_SPECIFIC_QT_TRANSLATION_FILES};passwordfile" PARENT_SCOPE)
    endif()

    # add Qt resources if it is a static library
    if (NOT PASSWORD_FILE_LIB_IS_SHARED)
        set(STATIC_LIBRARIES_QT_RESOURCES "${STATIC_LIBRARIES_QT_RESOURCES};${PASSWORD_FILE_QT_RESOURCES}" PARENT_SCOPE)
    endif()
endfunction()

==> static-compat-passwordfile-5.0.13-1-x86_64.pkg.tar.zst: usr/static-compat/share/passwordfile/cmake/passwordfileConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# provide meta-data
set(passwordfile_varname "PASSWORD_FILE")
set(passwordfile_varname "PASSWORD_FILE")
set(PASSWORD_FILE_DISPLAY_NAME "Passwordfile library")
set(PASSWORD_FILE_AUTHOR "Martchus")
set(PASSWORD_FILE_VERSION "5.0.13")
set(PASSWORD_FILE_VERSION_MAJOR "5")
set(PASSWORD_FILE_VERSION_MINOR "0")
set(PASSWORD_FILE_VERSION_PATCH "13")
set(PASSWORD_FILE_GIT_REV_COUNT "")
set(PASSWORD_FILE_GIT_LAST_COMMIT_ID "")
set(PASSWORD_FILE_URL "https://github.com/Martchus/passwordfile")
set(PASSWORD_FILE_DESCRIPTION "C++ library to read/write passwords from/to encrypted files")
set(PASSWORD_FILE_LICENSE "GPL-2.0+")

# define general config
set(PASSWORD_FILE_IS_HEADER_ONLY NO)
set(PASSWORD_FILE_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include")
set(PASSWORD_FILE_BIN_DIR "${PACKAGE_PREFIX_DIR}/bin")
set(PASSWORD_FILE_LIB_DIR "${PACKAGE_PREFIX_DIR}/lib")
set(PASSWORD_FILE_DATA_DIRS "${PACKAGE_PREFIX_DIR}/share/passwordfile")
set(PASSWORD_FILE_MODULE_DIRS "${PACKAGE_PREFIX_DIR}/share/passwordfile/cmake/modules")
set(PASSWORD_FILE_CONFIG_DIRS "${PACKAGE_PREFIX_DIR}/share/passwordfile/cmake")
set(PASSWORD_FILE_PRIVATE_QT_MODULES "")
set(PASSWORD_FILE_PRIVATE_KF_MODULES "")
set(PASSWORD_FILE_PUBLIC_QT_MODULES "")
set(PASSWORD_FILE_PUBLIC_KF_MODULES "")
set(PASSWORD_FILE_REQUIRED_PACKAGES "c++utilities;ZLIB;OpenSSL")
set(PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULES "")
set(PASSWORD_FILE_HAS_QT_TRANSLATION_FILES )
set(PASSWORD_FILE_QT_RESOURCES )

# define mapping from CMake targets to pkg-config module names
set(PKG_CONFIG_passwordfile "passwordfile")

# save policies before modifying them e.g. though the inclusion of 3rdParty
cmake_policy(PUSH)

# define additional find_package arguments for required CMake-packages

# define library config, add imported target
set(PASSWORD_FILE_PACKAGE "passwordfile")
set(PASSWORD_FILE_LIB "passwordfile")
set(PASSWORD_FILE_LIB_IS_SHARED "OFF")
set(PASSWORD_FILE_STATIC_LINKAGE "OFF")
if(NOT TARGET "${PASSWORD_FILE_LIB}")
    # make dependencies of the library available
    # caveat: This currently does *not* cover Qt and KF modules which are so far only handled
    #         separately when using the function use_PASSWORD_FILE.

    # find c++utilities to use its CMake modules
    if (NOT PASSWORD_FILE_PACKAGE STREQUAL "c++utilities")
        find_package("c++utilities" ${PASSWORD_FILE_FIND_PACKAGE_ARGS_c++utilities} REQUIRED)
    endif ()

    # prefer static libraries if passwordfile was configured this way during its build
    set(PASSWORD_FILE_DEFAULT_CMAKE_MODULE_PATH "${CMAKE_MODULE_PATH}")
    list(APPEND CMAKE_MODULE_PATH "${PASSWORD_FILE_MODULE_DIRS}")
    list(APPEND CMAKE_MODULE_PATH "${CPP_UTILITIES_MODULE_DIRS}")
    include(3rdPartyFunctions)
    if (PASSWORD_FILE_STATIC_LINKAGE)
        save_library_preference()
        prefer_static_libraries()
    endif ()

    # find all required packages
    foreach (_REQUIRED_PACKAGE ${PASSWORD_FILE_REQUIRED_PACKAGES})
        string(REGEX MATCH _REQUIRED_PACKAGE_MATCH "(.*)-([^-]*)" "${_REQUIRED_PACKAGE}")
        if (_REQUIRED_PACKAGE_MATCH)
            set(_REQUIRED_PACKAGE "${CMAKE_MATCH_1}")
            set(_REQUIRED_VERSION "${CMAKE_MATCH_2}")
        else ()
            unset(_REQUIRED_VERSION)
        endif ()
        string(REPLACE "::" "_" _REQUIRED_PACKAGE_VARNAME "${_REQUIRED_PACKAGE}")
        if (PASSWORD_FILE_FIND_PACKAGE_ARGS_${_REQUIRED_PACKAGE_VARNAME})
            set(_FIND_PACKAGE_ARGS ${PASSWORD_FILE_FIND_PACKAGE_ARGS_${_REQUIRED_PACKAGE_VARNAME}})
        else ()
            set(_FIND_PACKAGE_ARGS REQUIRED)
        endif ()
        if (_REQUIRED_VERSION)
            find_package("${_REQUIRED_PACKAGE}" "${_REQUIRED_VERSION}" ${_FIND_PACKAGE_ARGS})
        else ()
            find_package("${_REQUIRED_PACKAGE}" ${_FIND_PACKAGE_ARGS})
        endif()
    endforeach()

    # find all required pkg-config modules
    if (PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULES)
        foreach (PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULE ${PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULES})
            string(REPLACE "::" "_" PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULE_VARNAME "${PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULE}")
            use_pkg_config_module(
                TARGET_NAME "${PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULE}"
                PKG_CONFIG_MODULES "${PKG_CONFIG_${PASSWORD_FILE_REQUIRED_PKG_CONFIG_MODULE_VARNAME}}"
                LIBRARIES_VARIABLE DEV_NULL
                PKG_CONFIG_MODULES_VARIABLE DEV_NULL
            )
        endforeach ()
    endif ()

    # restore preference of static libraries
    if (PASSWORD_FILE_STATIC_LINKAGE)
        restore_library_preference()
    endif ()

    # add target for the library itself
    include("${CMAKE_CURRENT_LIST_DIR}/passwordfileTargets.cmake")

    # restore module path
    set(CMAKE_MODULE_PATH "${PASSWORD_FILE_DEFAULT_CMAKE_MODULE_PATH}")
endif()

# define function to ease use of library in projects following conventions of c++utilities' build script
function(use_PASSWORD_FILE)
    # make CMake modules of the project available
    list(APPEND CMAKE_MODULE_PATH "${PASSWORD_FILE_MODULE_DIRS}")
    set(CMAKE_MODULE_PATH "${CMAKE_MODULE_PATH}" PARENT_SCOPE)

    # parse arguments
    list(APPEND CMAKE_MODULE_PATH "${CPP_UTILITIES_MODULE_DIRS}")
    include(3rdParty)
    parse_arguments_for_use_functions(${ARGN})

    # link against library (also "link" against header-only libs to get compile defs and interface link libs)
    link_directories(${PASSWORD_FILE_LIB_DIR})
    if (ARGS_ONLY_HEADERS)
        set(TARGET_NAME "${PASSWORD_FILE_LIB}-headers")
    else ()
        set(TARGET_NAME "${PASSWORD_FILE_LIB}")
    endif ()
    set("${ARGS_LIBRARIES_VARIABLE}" "${${ARGS_LIBRARIES_VARIABLE}};${TARGET_NAME}" PARENT_SCOPE)
    set("${ARGS_PACKAGES_VARIABLE}" "${${ARGS_PACKAGES_VARIABLE}};${PASSWORD_FILE_PACKAGE}" PARENT_SCOPE)

    if (ARGS_ONLY_HEADERS)
        return ()
    endif ()

    # add required Qt and KF modules
    set(IMPORTED_QT_MODULES
        ${IMPORTED_QT_MODULES}
        ${PASSWORD_FILE_PUBLIC_QT_MODULES}
        ${PASSWORD_FILE_PRIVATE_QT_MODULES}
        PARENT_SCOPE
    )
    set(IMPORTED_KF_MODULES
        ${IMPORTED_KF_MODULES}
        ${PASSWORD_FILE_PUBLIC_KF_MODULES}
        ${PASSWORD_FILE_PRIVATE_KF_MODULES}
        PARENT_SCOPE
    )

    # add required translations to APP_SPECIFIC_QT_TRANSLATION_FILES_ARRAY
    if(PASSWORD_FILE_HAS_QT_TRANSLATION_FILES)
        set(APP_SPECIFIC_QT_TRANSLATION_FILES "${APP_SPECIFIC_QT_TRANSLATION_FILES};passwordfile" PARENT_SCOPE)
    endif()

    # add Qt resources if it is a static library
    if (NOT PASSWORD_FILE_LIB_IS_SHARED)
        set(STATIC_LIBRARIES_QT_RESOURCES "${STATIC_LIBRARIES_QT_RESOURCES};${PASSWORD_FILE_QT_RESOURCES}" PARENT_SCOPE)
    endif()
endfunction()

# restore policies
cmake_policy(POP)
